from django.shortcuts import render
from django.http import JsonResponse
import os
import rust_crud_api  # This is the module we built

def init_db_view(request):
    db_url = os.environ.get("DATABASE_URL")
    try:
        rust_crud_api.init_db(db_url)
        return JsonResponse({"message": "Database initialized"})
    except Exception as e:
        return JsonResponse({"error": str(e)}, status=500)

def create_user_view(request):
    db_url = os.environ.get("DATABASE_URL")
    name = request.POST.get("name", "Alice")
    email = request.POST.get("email", "alice@example.com")
    try:
        rust_crud_api.create_user(db_url, name, email)
        return JsonResponse({"message": "User created"})
    except Exception as e:
        return JsonResponse({"error": str(e)}, status=500)

def get_user_view(request, user_id):
    db_url = os.environ.get("DATABASE_URL")
    try:
        user = rust_crud_api.get_user(db_url, int(user_id))
        if user is None:
            return JsonResponse({"error": "User not found"}, status=404)
        return JsonResponse({
            "id": user.id,
            "name": user.name,
            "email": user.email
        })
    except Exception as e:
        return JsonResponse({"error": str(e)}, status=500)

